@@ -1,6 +1,6 @@
 ;;; doom-modeline-core.el --- The core libraries for doom-modeline -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2018-2025 Vincent Zhang
+;; Copyright (C) 2018-2026 Vincent Zhang
 
 ;; This file is not part of GNU Emacs.
 
@@ -261,7 +261,7 @@ See `doom-modeline-time-analogue-clock'."
 (defcustom doom-modeline-time-clock-size 0.7
   "Size of the analogue clock drawn, either in pixels or as a proportional height.
 An integer value is used as the diameter of clock in pixels.
-A floating point value sets the diameter of the clock realtive to
+A floating point value sets the diameter of the clock relative to
 `doom-modeline-height'.
 
 Only relevant when `doom-modeline-time-analogue-clock' is non-nil, which see."
@@ -1132,7 +1132,6 @@ Which are not explicitly listed in `doom-modeline-vcs-state-faces-alist'."
 ;;
 
 (declare-function doom-modeline-shorten-irc "doom-modeline-segments")
-(declare-function face-remap-remove-relative "face-remap")
 (declare-function ffip-project-root "ext:find-file-in-project")
 (declare-function project-root "project")
 (declare-function projectile-project-root "ext:projectile")
@@ -1217,9 +1216,11 @@ used as an advice to window creation functions."
   (and (featurep 'mwheel) (bound-and-true-p mouse-wheel-mode)))
 
 ;; Keep `doom-modeline-current-window' up-to-date
-(defun doom-modeline--selected-window ()
-  "Get the selected window."
-  (frame-selected-window))
+(defun doom-modeline--selected-window (&optional frame)
+  "Get the selected window of FRAME but should exclude the child windows."
+  (if (and (fboundp 'frame-parent) (frame-parent frame))
+      (frame-selected-window (frame-parent frame))
+    (frame-selected-window frame)))
 
 (defvar doom-modeline-current-window (doom-modeline--selected-window)
   "Current window.")
@@ -1255,9 +1256,10 @@ used as an advice to window creation functions."
 
 (defun doom-modeline-focus-change (&rest _)
   "Focus change."
-  (if (frame-focus-state)
-      (doom-modeline-set-selected-window)
-    (doom-modeline-unset-selected-window)))
+  ;; (if (frame-focus-state)
+  ;;     (doom-modeline-set-selected-window)
+  ;;   (doom-modeline-unset-selected-window))
+  )
 
 
 
